import { css } from "@linaria/core";
import { Button, Space, Table } from "ant-design-vue";
import { defineComponent } from "vue";

import { Image } from "@queenjs/ui";

import { useList } from "@/modules/list";

export default defineComponent({
  setup() {
    const { store, showModal } = useList();
    const columns = [
      {
        title: "文物名称",
        dataIndex: "name",
        key: "name",
      },
      {
        title: "封面图",
        dataIndex: "thumbnail",
        key: "thumbnail",
        customRender: ({ text }: any) => {
          return <Image class="thumbnail" src={text} size={120} />;
        },
      },
      {
        title: "展示形式",
        dataIndex: "type",
        key: "type",
        customRender: ({ text }: any) => {
          switch (text) {
            case "img":
              return "图片";
            case "video":
              return "视频";
            case "3D":
              return "模型";
          }
        },
      },
    ];

    return () => (
      <div class={ViewStyle}>
        <div class="table_header">
          <div class="title">文物列表</div>
          <div>
            <Space>
              <Button
                type="primary"
                ghost
                onClick={() => {
                  console.log(1);
                }}
              >
                导入资源
              </Button>
            </Space>
          </div>
        </div>
        <Table
          size="small"
          columns={columns}
          dataSource={store.list}
          rowKey={(record) => record?._id}
        ></Table>
      </div>
    );
  },
});

const ViewStyle = css`
  padding: 20px;
  .table_header {
    display: flex;
    align-items: center;
    justify-content: space-between;
    margin-bottom: 20px;
    .title {
      font-size: 18px;
      font-weight: bold;
    }
  }
  .ant-table-thead > tr > th,
  .ant-table-tbody > tr > td {
    text-align: center;
  }
  .thumbnail {
    width: 120px;
    object-fit: contain;
  }
`;
